#!/bin/bash -ex
# topo B-A-C creates the following network topology:
#
#
#     ns:B            ns:A            ns:C
#
#       B  --- br0 ---  A  --- br1 ---  C
#        b-a         a-b a-c         c-a
#
#
# should be run under unshare -mrun .
# use xnsenter {A,B,C} to enter into namespaces of A/B/C.
#
# Based on https://github.com/troglobit/smcroute/tree/master/test

. lib.sh


# lo on everything
xunshare A -- ip link set lo up
xunshare B -- ip link set lo up
xunshare C -- ip link set lo up

# links
xlink B A   # B-A
xlink A C   # A-C


# addresses
xnsenter B -- ip addr add 10.0.0.1/24 dev b-a
xnsenter A -- ip addr add 10.0.0.2/24 dev a-b
xnsenter C -- ip addr add 20.0.0.1/24 dev c-a
xnsenter A -- ip addr add 20.0.0.2/24 dev a-c

# multicast routing
xnsenter B -- ip route add 224.0.0.0/4 dev b-a
xnsenter C -- ip route add 224.0.0.0/4 dev c-a

xnsenter A -- ip route add    224.0.0.0/4 dev a-b   # NOTE on A 224.0.0.0/4 is routed
xnsenter A -- ip route append 224.0.0.0/4 dev a-c   # to _both_ a-b and a-c


# mount private /var/run so that smcrouted can be started
xnsenter A -- mount -t tmpfs none /var/run
xnsenter B -- mount -t tmpfs none /var/run
xnsenter C -- mount -t tmpfs none /var/run


# open terminals in A B C for play
xnsenter B -- xfce4-terminal --title=B &
xnsenter C -- xfce4-terminal --title=C &
xnsenter A -- xfce4-terminal --title=A &
xnsenter A -- xfce4-terminal --title=A2 &
